var structjs_stream_source =
[
    [ "Name", "structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3", null ],
    [ "OptStartSeq", "structjs_stream_source.html#ad6948b7a34c202f324b6d2beb32fe5ed", null ],
    [ "OptStartTime", "structjs_stream_source.html#a67eb1dac41b2d826a923cfb23baa24a5", null ],
    [ "FilterSubject", "structjs_stream_source.html#af787b51dde9d77626f33860564eb08c3", null ],
    [ "External", "structjs_stream_source.html#a295458d156af5373bb3f5ab06612a888", null ],
    [ "Domain", "structjs_stream_source.html#aa304239ee823ef87fcb53ebb0c077e7b", null ]
];